==> odata-client-microsoft-dynamics-0.1.38-sources.jar: microsoft/dynamics/crm/entity/request/MobileofflineprofileitemassociationRequest.java <==
package microsoft.dynamics.crm.entity.request;

import com.fasterxml.jackson.annotation.JsonIgnoreType;
import com.github.davidmoten.odata.client.ContextPath;
import com.github.davidmoten.odata.client.EntityRequest;

import java.lang.Object;
import java.util.Optional;

import microsoft.dynamics.crm.entity.Mobileofflineprofileitemassociation;
import microsoft.dynamics.crm.schema.SchemaInfo;

@JsonIgnoreType
public class MobileofflineprofileitemassociationRequest extends EntityRequest<Mobileofflineprofileitemassociation> {

    public MobileofflineprofileitemassociationRequest(ContextPath contextPath, Optional<Object> value) {
        super(Mobileofflineprofileitemassociation.class, contextPath, SchemaInfo.INSTANCE, value);
    }

    public SystemuserRequest modifiedonbehalfby() {
        return new SystemuserRequest(contextPath.addSegment("modifiedonbehalfby"), Optional.empty());
    }

    public SystemuserRequest modifiedby() {
        return new SystemuserRequest(contextPath.addSegment("modifiedby"), Optional.empty());
    }

    public OrganizationRequest organizationid() {
        return new OrganizationRequest(contextPath.addSegment("organizationid"), Optional.empty());
    }

    public MobileofflineprofileitemRequest regardingobjectid() {
        return new MobileofflineprofileitemRequest(contextPath.addSegment("regardingobjectid"), Optional.empty());
    }

    public SystemuserRequest createdby() {
        return new SystemuserRequest(contextPath.addSegment("createdby"), Optional.empty());
    }

    public SystemuserRequest createdonbehalfby() {
        return new SystemuserRequest(contextPath.addSegment("createdonbehalfby"), Optional.empty());
    }

}

==> odata-client-microsoft-dynamics-0.1.39-sources.jar: microsoft/dynamics/crm/entity/request/MobileofflineprofileitemassociationRequest.java <==
package microsoft.dynamics.crm.entity.request;

import com.fasterxml.jackson.annotation.JsonIgnoreType;
import com.github.davidmoten.odata.client.ContextPath;
import com.github.davidmoten.odata.client.EntityRequest;

import java.lang.Object;
import java.util.Optional;

import microsoft.dynamics.crm.entity.Mobileofflineprofileitemassociation;

@JsonIgnoreType
public class MobileofflineprofileitemassociationRequest extends EntityRequest<Mobileofflineprofileitemassociation> {

    public MobileofflineprofileitemassociationRequest(ContextPath contextPath, Optional<Object> value) {
        super(Mobileofflineprofileitemassociation.class, contextPath, value);
    }

    public SystemuserRequest modifiedonbehalfby() {
        return new SystemuserRequest(contextPath.addSegment("modifiedonbehalfby"), Optional.empty());
    }

    public SystemuserRequest modifiedby() {
        return new SystemuserRequest(contextPath.addSegment("modifiedby"), Optional.empty());
    }

    public OrganizationRequest organizationid() {
        return new OrganizationRequest(contextPath.addSegment("organizationid"), Optional.empty());
    }

    public MobileofflineprofileitemRequest regardingobjectid() {
        return new MobileofflineprofileitemRequest(contextPath.addSegment("regardingobjectid"), Optional.empty());
    }

    public SystemuserRequest createdby() {
        return new SystemuserRequest(contextPath.addSegment("createdby"), Optional.empty());
    }

    public SystemuserRequest createdonbehalfby() {
        return new SystemuserRequest(contextPath.addSegment("createdonbehalfby"), Optional.empty());
    }

}
